@@ -19,7 +19,6 @@ import (
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/util/retry"
 	"k8s.io/kubernetes/test/e2e/framework"
-	"k8s.io/kubernetes/test/e2e/lifecycle"
 	"k8s.io/kubernetes/test/e2e/upgrades"
 	apps "k8s.io/kubernetes/test/e2e/upgrades/apps"
 
@@ -27,6 +26,7 @@ import (
 
 	configv1 "github.com/openshift/api/config/v1"
 	configv1client "github.com/openshift/client-go/config/clientset/versioned"
+	"github.com/openshift/origin/test/e2e/upgrade/alert"
 	"github.com/openshift/origin/test/e2e/upgrade/service"
 	"github.com/openshift/origin/test/extended/util/disruption"
 	"github.com/openshift/origin/test/extended/util/disruption/controlplane"
@@ -35,7 +35,9 @@ import (
 
 func AllTests() []upgrades.Test {
 	return []upgrades.Test{
-		&controlplane.AvailableTest{},
+		&controlplane.KubeAvailableTest{},
+		&controlplane.OpenShiftAvailableTest{},
+		&alert.UpgradeTest{},
 		&frontends.AvailableTest{},
 		&service.UpgradeTest{},
 		&upgrades.SecretUpgradeTest{},
@@ -49,6 +51,7 @@ func AllTests() []upgrades.Test {
 }
 
 var (
+	upgradeToImage             string
 	upgradeTests               = []upgrades.Test{}
 	upgradeAbortAt             int
 	upgradeDisruptRebootPolicy string
@@ -64,6 +67,12 @@ func SetTests(tests []upgrades.Test) {
 	upgradeTests = tests
 }
 
+// SetToImage sets the image that will be upgraded to. This may be a comma delimited list
+// of sequential upgrade attempts.
+func SetToImage(image string) {
+	upgradeToImage = image
+}
+
 func SetUpgradeDisruptReboot(policy string) error {
 	switch policy {
 	case "graceful", "force":
@@ -114,8 +123,8 @@ var _ = g.Describe("[Disruptive]", func() {
 			client := configv1client.NewForConfigOrDie(config)
 			dynamicClient := dynamic.NewForConfigOrDie(config)
 
-			upgCtx, err := getUpgradeContext(client, lifecycle.GetUpgradeImage())
-			framework.ExpectNoError(err, "determining what to upgrade to version=%s image=%s", "", lifecycle.GetUpgradeImage())
+			upgCtx, err := getUpgradeContext(client, upgradeToImage)
+			framework.ExpectNoError(err, "determining what to upgrade to version=%s image=%s", "", upgradeToImage)
 
 			disruption.Run(
 				"Cluster upgrade",
