@@ -7,6 +7,10 @@ import (
 	g "github.com/onsi/ginkgo"
 	o "github.com/onsi/gomega"
 
+	apiextensionsclientset "k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset"
+	apiextensionsscheme "k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset/scheme"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	e2e "k8s.io/kubernetes/test/e2e/framework"
 
@@ -41,20 +45,22 @@ var (
 	}
 
 	crdTypes = []schema.GroupVersionResource{
-		{Group: "operators.coreos.com", Version: "v1", Resource: "catalogsourceconfigs"},
-		// FIXME:
+		// FIXME
+		// {Group: "operators.coreos.com", Version: "v1", Resource: "catalogsourceconfigs"},
 		// {Group: "operators.coreos.com", Version: "v1", Resource: "catalogsources"},
 		// {Group: "operators.coreos.com", Version: "v1", Resource: "clusterserviceversions"},
 		// {Group: "operators.coreos.com", Version: "v1", Resource: "installplans"},
-		{Group: "operators.coreos.com", Version: "v1", Resource: "operatorgroups"},
-		{Group: "operators.coreos.com", Version: "v1", Resource: "operatorsources"},
-		// FIXME:
+		// {Group: "operators.coreos.com", Version: "v1", Resource: "operatorgroups"},
+		// {Group: "operators.coreos.com", Version: "v1", Resource: "operatorsources"},
 		// {Group: "operators.coreos.com", Version: "v1", Resource: "subscriptions"},
 
-		{Group: "autoscaling.openshift.io", Version: "v1", Resource: "clusterautoscalers"},
-		// FIXME:
+		// FIXME
+		// {Group: "autoscaling.openshift.io", Version: "v1", Resource: "clusterautoscalers"},
 		// {Group: "autoscaling.openshift.io", Version: "v1", Resource: "machineautoscalers"},
 
+		{Group: "authorization.openshift.io", Version: "v1", Resource: "selfsubjectrulesreviews"},
+		{Group: "authorization.openshift.io", Version: "v1", Resource: "subjectrulesreviews"},
+
 		{Group: "config.openshift.io", Version: "v1", Resource: "apiservers"},
 		{Group: "config.openshift.io", Version: "v1", Resource: "authentications"},
 		{Group: "config.openshift.io", Version: "v1", Resource: "builds"},
@@ -68,22 +74,29 @@ var (
 		{Group: "config.openshift.io", Version: "v1", Resource: "ingresses"},
 		{Group: "config.openshift.io", Version: "v1", Resource: "networks"},
 		{Group: "config.openshift.io", Version: "v1", Resource: "oauths"},
+		{Group: "config.openshift.io", Version: "v1", Resource: "operatorhubs"},
 		{Group: "config.openshift.io", Version: "v1", Resource: "projects"},
+		{Group: "config.openshift.io", Version: "v1", Resource: "proxies"},
 		{Group: "config.openshift.io", Version: "v1", Resource: "schedulers"},
 
-		{Group: "cloudcredential.openshift.io", Version: "v1", Resource: "credentialsrequests"},
+		// FIXME
+		// {Group: "cloudcredential.openshift.io", Version: "v1", Resource: "credentialsrequests"},
 
 		// FIXME
 		// {Group: "healthchecking.openshift.io", Version: "v1", Resource: "machinehealthchecks"},
 		// {Group: "imageregistry.operator.openshift", Version: "v1", Resource: "configs"},
 
-		{Group: "machine.openshift.io", Version: "v1beta1", Resource: "machines"},
-		{Group: "machine.openshift.io", Version: "v1beta1", Resource: "machinesets"},
+		// FIXME
+		// {Group: "machine.openshift.io", Version: "v1beta1", Resource: "machinedisruptionbudgets"},
+		// {Group: "machine.openshift.io", Version: "v1beta1", Resource: "machinehealthchecks"},
+		// {Group: "machine.openshift.io", Version: "v1beta1", Resource: "machines"},
+		// {Group: "machine.openshift.io", Version: "v1beta1", Resource: "machinesets"},
 
-		{Group: "monitoring.coreos.com", Version: "v1", Resource: "alertmanagers"},
-		{Group: "monitoring.coreos.com", Version: "v1", Resource: "prometheuses"},
-		{Group: "monitoring.coreos.com", Version: "v1", Resource: "prometheusrules"},
-		{Group: "monitoring.coreos.com", Version: "v1", Resource: "servicemonitors"},
+		// FIXME
+		// {Group: "monitoring.coreos.com", Version: "v1", Resource: "alertmanagers"},
+		// {Group: "monitoring.coreos.com", Version: "v1", Resource: "prometheuses"},
+		// {Group: "monitoring.coreos.com", Version: "v1", Resource: "prometheusrules"},
+		// {Group: "monitoring.coreos.com", Version: "v1", Resource: "servicemonitors"},
 
 		// FIXME
 		// {Group: "machineconfiguration.openshift.io", Version: "v1", Resource: "containerruntimeconfigs"},
@@ -93,22 +106,34 @@ var (
 		// {Group: "machineconfiguration.openshift.io", Version: "v1", Resource: "machineconfigs"},
 		// {Group: "machineconfiguration.openshift.io", Version: "v1", Resource: "mcoconfigs"},
 
-		{Group: "operator.openshift.io", Version: "v1", Resource: "authentications"},
+		{Group: "operator.openshift.io", Version: "v1alpha1", Resource: "imagecontentsourcepolicies"},
+
 		{Group: "operator.openshift.io", Version: "v1", Resource: "consoles"},
-		{Group: "operator.openshift.io", Version: "v1", Resource: "dnses"},
+		{Group: "operator.openshift.io", Version: "v1", Resource: "openshiftapiservers"},
+
+		// FIXME
+		// {Group: "operator.openshift.io", Version: "v1", Resource: "credentialsrequestses"},
+		// {Group: "operator.openshift.io", Version: "v1", Resource: "networks"},
+		{Group: "operator.openshift.io", Version: "v1", Resource: "authentications"},
 		{Group: "operator.openshift.io", Version: "v1", Resource: "ingresscontrollers"},
 		{Group: "operator.openshift.io", Version: "v1", Resource: "kubeapiservers"},
 		{Group: "operator.openshift.io", Version: "v1", Resource: "kubecontrollermanagers"},
 		{Group: "operator.openshift.io", Version: "v1", Resource: "kubeschedulers"},
-		{Group: "operator.openshift.io", Version: "v1", Resource: "networks"},
-		{Group: "operator.openshift.io", Version: "v1", Resource: "openshiftapiservers"},
 		{Group: "operator.openshift.io", Version: "v1", Resource: "openshiftcontrollermanagers"},
 		{Group: "operator.openshift.io", Version: "v1", Resource: "servicecas"},
 		{Group: "operator.openshift.io", Version: "v1", Resource: "servicecatalogapiservers"},
 		{Group: "operator.openshift.io", Version: "v1", Resource: "servicecatalogcontrollermanagers"},
 
+		{Group: "quota.openshift.io", Version: "v1", Resource: "appliedclusterresourcequotas"},
+
 		{Group: "quota.openshift.io", Version: "v1", Resource: "clusterresourcequotas"},
 
+		// FIXME
+		// {Group: "imageregistry.operator.openshift.io", Version: "v1", Resource: "configs"},
+
+		// FIXME
+		// {Group: "ingress.operator.openshift.io", Version: "v1", Resource: "dnsrecords"},
+
 		{Group: "samples.operator.openshift.io", Version: "v1", Resource: "configs"},
 
 		{Group: "tuned.openshift.io", Version: "v1", Resource: "tuneds"},
@@ -127,19 +152,54 @@ var (
 		},
 		{
 			gv:      schema.GroupVersion{Group: "authorization.openshift.io", Version: "v1"},
-			field:   "resourceaccessreviews.resourceAPIGroup",
-			pattern: `FIELD\: +resourceAPIGroup`,
+			field:   "clusterrolebindings.userNames",
+			pattern: `FIELD\: +userNames`,
 		},
 		{
 			gv:      schema.GroupVersion{Group: "authorization.openshift.io", Version: "v1"},
-			field:   "resourceaccessreviews.resourceAPIVersion",
-			pattern: `FIELD\: +resourceAPIVersion`,
+			field:   "clusterroles.rules",
+			pattern: `FIELDS\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "authorization.openshift.io", Version: "v1"},
+			field:   "localresourceaccessreviews",
+			pattern: `FIELDS\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "authorization.openshift.io", Version: "v1"},
+			field:   "localsubjectaccessreviews",
+			pattern: `FIELDS\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "authorization.openshift.io", Version: "v1"},
+			field:   "resourceaccessreviews",
+			pattern: `FIELDS\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "authorization.openshift.io", Version: "v1"},
+			field:   "resourceaccessreviews",
+			pattern: `FIELDS\:.*`,
 		},
 		{
 			gv:      schema.GroupVersion{Group: "authorization.openshift.io", Version: "v1"},
 			field:   "rolebindingrestrictions.spec",
 			pattern: `FIELDS\:.*`,
 		},
+		{
+			gv:      schema.GroupVersion{Group: "authorization.openshift.io", Version: "v1"},
+			field:   "rolebindings.userNames",
+			pattern: `FIELD\: +userNames`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "authorization.openshift.io", Version: "v1"},
+			field:   "roles.rules",
+			pattern: `FIELDS\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "authorization.openshift.io", Version: "v1"},
+			field:   "subjectaccessreviews.scopes",
+			pattern: `FIELD\: +scopes`,
+		},
 		{
 			gv:      schema.GroupVersion{Group: "image.openshift.io", Version: "v1"},
 			field:   "images.dockerImageReference",
@@ -225,6 +285,59 @@ var (
 			field:   "users.fullName",
 			pattern: `FIELD\: +fullName`,
 		},
+		{
+			gv:      schema.GroupVersion{Group: "security.openshift.io", Version: "v1"},
+			field:   "securitycontextconstraints",
+			pattern: `FIELDS\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "console.openshift.io", Version: "v1"},
+			field:   "consoleclidownloads.spec",
+			pattern: `DESCRIPTION\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "console.openshift.io", Version: "v1"},
+			field:   "consoleexternalloglinks.spec",
+			pattern: `DESCRIPTION\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "console.openshift.io", Version: "v1"},
+			field:   "consolelinks.spec",
+			pattern: `DESCRIPTION\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "console.openshift.io", Version: "v1"},
+			field:   "consolenotifications.spec",
+			pattern: `DESCRIPTION\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "console.openshift.io", Version: "v1"},
+			field:   "consoleyamlsamples.spec",
+			pattern: `DESCRIPTION\:.*`,
+		},
+	}
+
+	specialNetworkingTypes = []explainExceptions{
+		{
+			gv:      schema.GroupVersion{Group: "network.openshift.io", Version: "v1"},
+			field:   "clusternetworks",
+			pattern: `DESCRIPTION\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "network.openshift.io", Version: "v1"},
+			field:   "hostsubnets",
+			pattern: `DESCRIPTION\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "network.openshift.io", Version: "v1"},
+			field:   "netnamespaces",
+			pattern: `DESCRIPTION\:.*`,
+		},
+		{
+			gv:      schema.GroupVersion{Group: "network.openshift.io", Version: "v1"},
+			field:   "egressnetworkpolicies",
+			pattern: `DESCRIPTION\:.*`,
+		},
 	}
 )
 
@@ -236,41 +349,66 @@ var _ = g.Describe("[cli] oc explain", func() {
 	g.It("should contain spec+status for builtinTypes", func() {
 		for _, bt := range builtinTypes {
 			e2e.Logf("Checking %s...", bt)
-			o.Expect(verifySpecStatusExplain(oc, bt)).NotTo(o.HaveOccurred())
+			o.Expect(verifySpecStatusExplain(oc, nil, bt)).NotTo(o.HaveOccurred())
 		}
 	})
 
 	g.It("should contain proper spec+status for CRDs", func() {
+		crdClient := apiextensionsclientset.NewForConfigOrDie(oc.AdminConfig())
 		for _, ct := range crdTypes {
 			e2e.Logf("Checking %s...", ct)
-			o.Expect(verifyCRDSpecStatusExplain(oc, ct)).NotTo(o.HaveOccurred())
+			o.Expect(verifyCRDSpecStatusExplain(oc, crdClient, ct)).NotTo(o.HaveOccurred())
 		}
 	})
 
 	g.It("should contain proper fields description for special types", func() {
 		for _, st := range specialTypes {
 			e2e.Logf("Checking %s, Field=%s...", st.gv, st.field)
-			o.Expect(verifyExplain(oc, st.pattern, st.field, fmt.Sprintf("--api-version=%s", st.gv))).NotTo(o.HaveOccurred())
+			o.Expect(verifyExplain(oc, nil, schema.GroupVersionResource{},
+				st.pattern, st.field, fmt.Sprintf("--api-version=%s", st.gv))).NotTo(o.HaveOccurred())
 		}
 	})
 })
 
-func verifySpecStatusExplain(oc *exutil.CLI, gvr schema.GroupVersionResource) error {
-	return verifyExplain(oc, `(?s)DESCRIPTION:.*FIELDS:.*spec.*<Object>.*[Ss]pec(ification)?.*status.*<Object>.*[Ss]tatus.*`, gvr.Resource, fmt.Sprintf("--api-version=%s", gvr.GroupVersion()))
+var _ = g.Describe("[cli] oc explain networking types", func() {
+	defer g.GinkgoRecover()
+
+	oc := exutil.NewCLI("oc-explain", exutil.KubeConfigPath())
+
+	g.It("should contain proper fields description for special networking types", func() {
+		for _, st := range specialNetworkingTypes {
+			e2e.Logf("Checking %s, Field=%s...", st.gv, st.field)
+			o.Expect(verifyExplain(oc, nil, schema.GroupVersionResource{},
+				st.pattern, st.field, fmt.Sprintf("--api-version=%s", st.gv))).NotTo(o.HaveOccurred())
+		}
+	})
+})
+
+func verifySpecStatusExplain(oc *exutil.CLI, crdClient apiextensionsclientset.Interface, gvr schema.GroupVersionResource) error {
+	return verifyExplain(oc, crdClient, gvr,
+		`(?s)DESCRIPTION:.*FIELDS:.*spec.*<Object>.*[Ss]pec(ification)?.*status.*<Object>.*[Ss]tatus.*`,
+		gvr.Resource, fmt.Sprintf("--api-version=%s", gvr.GroupVersion()))
 }
 
-func verifyCRDSpecStatusExplain(oc *exutil.CLI, gvr schema.GroupVersionResource) error {
+func verifyCRDSpecStatusExplain(oc *exutil.CLI, crdClient apiextensionsclientset.Interface, gvr schema.GroupVersionResource) error {
 	// TODO ideally we'd want to check for reasonable description in both spec and status
-	return verifyExplain(oc, `(?s)DESCRIPTION:.*FIELDS:.*spec.*<.*>.*(status.*<.*>.*)?`, gvr.Resource, fmt.Sprintf("--api-version=%s", gvr.GroupVersion()))
+	return verifyExplain(oc, crdClient, gvr,
+		`(?s)DESCRIPTION:.*FIELDS:.*spec.*<.*>.*(status.*<.*>.*)?`,
+		gvr.Resource, fmt.Sprintf("--api-version=%s", gvr.GroupVersion()))
 }
 
-func verifyExplain(oc *exutil.CLI, pattern string, args ...string) error {
+func verifyExplain(oc *exutil.CLI, crdClient apiextensionsclientset.Interface, gvr schema.GroupVersionResource, pattern string, args ...string) error {
 	result, err := oc.Run("explain").Args(args...).Output()
 	if err != nil {
 		return fmt.Errorf("failed to explain %q: %v", args, err)
 	}
 	r := regexp.MustCompile(pattern)
 	if !r.Match([]byte(result)) {
+		if crdClient != nil {
+			if crd, err := crdClient.ApiextensionsV1().CustomResourceDefinitions().Get(gvr.GroupResource().String(), metav1.GetOptions{}); err == nil {
+				e2e.Logf("CRD yaml is:\n%s\n", runtime.EncodeOrDie(apiextensionsscheme.Codecs.LegacyCodec(apiextensionsscheme.Scheme.PrioritizedVersionsAllGroups()...), crd))
+			}
+		}
 		return fmt.Errorf("oc explain %q result {%s} doesn't match pattern {%s}", args, result, pattern)
 	}
 	return nil
