@@ -91,6 +91,18 @@ type resourceRef struct {
 	Name      string
 }
 
+// NewCLIWithFramework initializes the CLI using the provided Kube
+// framework. It can be called inside of a Ginkgo .It() function.
+func NewCLIWithFramework(kubeFramework *e2e.Framework) *CLI {
+	cli := &CLI{
+		kubeFramework:   kubeFramework,
+		username:        "admin",
+		execPath:        "oc",
+		adminConfigPath: KubeConfigPath(),
+	}
+	return cli
+}
+
 // NewCLI initialize the upstream E2E framework and set the namespace to match
 // with the project name. Note that this function does not initialize the project
 // role bindings for the namespace.
@@ -198,6 +210,13 @@ func (c *CLI) SetupProject() {
 	_, err := c.ProjectClient().ProjectV1().ProjectRequests().Create(&projectv1.ProjectRequest{
 		ObjectMeta: metav1.ObjectMeta{Name: newNamespace},
 	})
+	if apierrors.IsForbidden(err) {
+		err = c.setupSelfProvisionerRoleBinding()
+		o.Expect(err).NotTo(o.HaveOccurred())
+		_, err = c.ProjectClient().ProjectV1().ProjectRequests().Create(&projectv1.ProjectRequest{
+			ObjectMeta: metav1.ObjectMeta{Name: newNamespace},
+		})
+	}
 	o.Expect(err).NotTo(o.HaveOccurred())
 
 	c.kubeFramework.AddNamespacesToDelete(&corev1.Namespace{ObjectMeta: metav1.ObjectMeta{Name: newNamespace}})
@@ -263,9 +282,34 @@ func (c *CLI) SetupProject() {
 		o.Expect(err).NotTo(o.HaveOccurred())
 	}
 
+	WaitForNamespaceSCCAnnotations(c.ProjectClient().ProjectV1(), newNamespace)
+
 	e2e.Logf("Project %q has been fully provisioned.", newNamespace)
 }
 
+func (c *CLI) setupSelfProvisionerRoleBinding() error {
+	e2e.Logf("Creating role binding to allow self provisioning of projects")
+	rb := &rbacv1.ClusterRoleBinding{
+		ObjectMeta: metav1.ObjectMeta{
+			Name: "e2e-self-provisioners",
+		},
+		RoleRef: rbacv1.RoleRef{
+			APIGroup: rbacv1.SchemeGroupVersion.Group,
+			Kind:     "ClusterRole",
+			Name:     "self-provisioner",
+		},
+		Subjects: []rbacv1.Subject{
+			{
+				APIGroup: rbacv1.SchemeGroupVersion.Group,
+				Kind:     "Group",
+				Name:     "system:authenticated:oauth",
+			},
+		},
+	}
+	_, err := c.AdminKubeClient().RbacV1().ClusterRoleBindings().Create(rb)
+	return err
+}
+
 // SetupProject creates a new project and assign a random user to the project.
 // All resources will be then created within this project.
 // TODO this should be removed.  It's only used by image tests.
@@ -275,6 +319,13 @@ func (c *CLI) CreateProject() string {
 	_, err := c.ProjectClient().ProjectV1().ProjectRequests().Create(&projectv1.ProjectRequest{
 		ObjectMeta: metav1.ObjectMeta{Name: newNamespace},
 	})
+	if apierrors.IsForbidden(err) {
+		err = c.setupSelfProvisionerRoleBinding()
+		o.Expect(err).NotTo(o.HaveOccurred())
+		_, err = c.ProjectClient().ProjectV1().ProjectRequests().Create(&projectv1.ProjectRequest{
+			ObjectMeta: metav1.ObjectMeta{Name: newNamespace},
+		})
+	}
 	o.Expect(err).NotTo(o.HaveOccurred())
 
 	actualNs, err := c.AdminKubeClient().CoreV1().Namespaces().Get(newNamespace, metav1.GetOptions{})
@@ -473,7 +524,7 @@ func (c *CLI) Run(commands ...string) *CLI {
 		configPath:      c.configPath,
 		username:        c.username,
 		globalArgs: append([]string{
-			fmt.Sprintf("--config=%s", c.configPath),
+			fmt.Sprintf("--kubeconfig=%s", c.configPath),
 		}, commands...),
 	}
 	if !c.withoutNamespace {
