@@ -60,9 +60,9 @@ type Definition struct {
 // NewRef creates a jenkins reference from an OC client
 func NewRef(oc *exutil.CLI) *JenkinsRef {
 	g.By("get ip and port for jenkins service")
-	serviceIP, err := oc.Run("get").Args("svc", "jenkins", "--config", exutil.KubeConfigPath()).Template("{{.spec.clusterIP}}").Output()
+	serviceIP, err := oc.Run("get").Args("svc", "jenkins", "--kubeconfig", exutil.KubeConfigPath()).Template("{{.spec.clusterIP}}").Output()
 	o.Expect(err).NotTo(o.HaveOccurred())
-	port, err := oc.Run("get").Args("svc", "jenkins", "--config", exutil.KubeConfigPath()).Template("{{ $x := index .spec.ports 0}}{{$x.port}}").Output()
+	port, err := oc.Run("get").Args("svc", "jenkins", "--kubeconfig", exutil.KubeConfigPath()).Template("{{ $x := index .spec.ports 0}}{{$x.port}}").Output()
 	o.Expect(err).NotTo(o.HaveOccurred())
 
 	g.By("get token via whoami")
